=======
Xentica
=======
**GPU-Accelerated Engine For Multi-Dimensional Cellular Automata**

.. image:: https://travis-ci.org/a5kin/xentica.png?branch=master
    :target: https://travis-ci.org/a5kin/xentica?branch=master
    :alt: Build Status

.. image:: https://readthedocs.org/projects/xentica/badge/?version=latest
    :target: http://xentica.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://api.codacy.com/project/badge/Grade/6f4fac8ce45d4781aa34607922754a71
    :target: https://www.codacy.com/app/a5kin/xentica?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=a5kin/xentica&amp;utm_campaign=Badge_Grade
    :alt: Codacy Badge

.. image:: https://img.shields.io/pypi/v/xentica.svg
    :target: https://pypi.org/project/xentica/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/pyversions/xentica.svg
    :target: https://pypi.org/project/xentica/
    :alt: Supported Python versions

.. image:: http://artipixoids.a5kin.net/assets/images/banners/xentica.png
    :alt: XENTICA Core Engine

**Xentica** is the core framework for the `Artipixoids!`_ project,
helping us to build GPU-accelerated models for multi-dimensional
cellular automata. Given pure Python definitions, Xentica generates
corresponding C code and runs it on GPU hardware.

For more information, please refer to the official `Xentica Documentation`_.

Another point of interest is `The Concept`_ document, explaining the
main goals of the project and giving formal definitions to all features
of the Core Framework.

The project is Open Source, `contributions`_ are welcome.

.. _Artipixoids!: http://artipixoids.a5kin.net/
.. _Xentica Documentation: http://xentica.readthedocs.io/
.. _The Concept: http://artipixoids.a5kin.net/concept/artipixoids_concept.pdf
.. _contributions: https://github.com/a5kin/xentica/blob/master/CONTRIBUTING.md
